@@ -121,7 +121,7 @@ def jslint(files, fix = False, relax = False, fail = True):
         console.fail( ' :puke:\n' + error.group())
 
 
-def jsdoc(files, folder, template = None, fail = False):
+def jsdoc(files, folder, template = None, fail = True):
     files = FileList.check(files)
 
     if not template:
